@@ -4,7 +4,7 @@ from .. import regex as re_
 from ..data.ingredient_funnel import dictionary as ing_funnel
 import numpy as np
 import unicodedata
-import unidecode
+from unidecode import unidecode
 
 class RecipeReader:
     def __init__(self):
@@ -31,7 +31,7 @@ class RecipeReader:
         phrase = re.sub(r'(?<=[a-z])/[a-z]+', '', phrase)
         phrase = re.sub(r'\b(?:5|five)[- ]?spice', 'fivespice', phrase)
         phrase = re.sub(r'.*: ?', '', phrase)
-        phrase = re.sub(r'\s+', ' ')
+        phrase = re.sub(r'\s+', ' ', phrase)
         phrase = phrase.strip()
 
 
