@@ -175,33 +175,33 @@ from .data.meat import dictionary as dict_meat
 from .data.ingredients import dictionary as dict_ing
 from .data.constants import u_substitutions, n_substitutions, s_substitutions
 import re
-from tokenizers import normalizers, Regex
-from tokenizers.normalizers import NFD, StripAccents, Replace, Sequence, Strip, Lowercase
+# from tokenizers import normalizers, Regex
+# from tokenizers.normalizers import NFD, StripAccents, Replace, Sequence, Strip, Lowercase
 
-normalizer = normalizers.Sequence([
-    NFD(),
-    StripAccents(),
-    Lowercase(),
-    Replace(Regex(r'\([^)]*\)'), ''), # remove parentheses contents
-    Replace(Regex(r'\(|\)'), ''),
-    Sequence([
-        Replace(Regex(vulgar_fraction), ' ' + fraction_str + ' ') # fix vulgar fractions
-        for vulgar_fraction, fraction_str in vf.dictionary.items()
-    ]),
-    Replace('–', '-'),
-    Replace('⁄', '/'),
-    Replace(Regex(r'half ?(?:and|-) ?half'), 'half-and-half'),
-    Replace(Regex(r'\.\.+'), ''), # remove ellipses
-    Replace(Regex(r' *\. *(?![0-9])'), '. '), # fix spaces around '.' symbol
-    Replace(Regex(r'(?<=[0-9]) *\. *(?=[0-9])'), '.'), # fix spaces around '.' symbol
-    Replace(Regex(r" '"), "'"),
-    Replace(Regex(r'(,[^,]+)?< ?a href.*'), ''), # remove html reference
-    Replace(Regex(r'(?<=[a-z])/[a-z]+'), ''), # fix multiword options i.e. and/or, chicken/beef
-    Replace(Regex(r'\b(?:5|five)[- ]?spice'), 'fivespice'),
-    Replace(Regex(r'.*: ?'), ''),
-    Replace(Regex(r'\s+'), ' '), # squish whitespace
-    Strip()
-])
+# normalizer = normalizers.Sequence([
+#     NFD(),
+#     StripAccents(),
+#     Lowercase(),
+#     Replace(Regex(r'\([^)]*\)'), ''), # remove parentheses contents
+#     Replace(Regex(r'\(|\)'), ''),
+#     Sequence([
+#         Replace(Regex(vulgar_fraction), ' ' + fraction_str + ' ') # fix vulgar fractions
+#         for vulgar_fraction, fraction_str in vf.dictionary.items()
+#     ]),
+#     Replace('–', '-'),
+#     Replace('⁄', '/'),
+#     Replace(Regex(r'half ?(?:and|-) ?half'), 'half-and-half'),
+#     Replace(Regex(r'\.\.+'), ''), # remove ellipses
+#     Replace(Regex(r' *\. *(?![0-9])'), '. '), # fix spaces around '.' symbol
+#     Replace(Regex(r'(?<=[0-9]) *\. *(?=[0-9])'), '.'), # fix spaces around '.' symbol
+#     Replace(Regex(r" '"), "'"),
+#     Replace(Regex(r'(,[^,]+)?< ?a href.*'), ''), # remove html reference
+#     Replace(Regex(r'(?<=[a-z])/[a-z]+'), ''), # fix multiword options i.e. and/or, chicken/beef
+#     Replace(Regex(r'\b(?:5|five)[- ]?spice'), 'fivespice'),
+#     Replace(Regex(r'.*: ?'), ''),
+#     Replace(Regex(r'\s+'), ' '), # squish whitespace
+#     Strip()
+# ])
 
 
 def P_vulgar_fractions(phrase):
@@ -468,5 +468,4 @@ def ingredient_fixer(ingredient, morequent_ingredients):
     elif most_frequent_match:
         return most_frequent_match
     else:
-        return ingredient
-
+        return ingredient
\ No newline at end of file
